==> maps_suite-7.x-2.0.tar.gz: maps_suite/modules/links/lib/Drupal/maps_links/Mapping/Link.php <==
<?php

namespace Drupal\maps_links\Mapping;

use Drupal\maps\Log\Context\Context as LogContext;
use Drupal\maps_import\Mapping\Mapping;
use Drupal\maps_import\Mapping\Mapper\Mapper;
use Drupal\maps_import\Mapping\Source\MapsSystem as MS;
use Drupal\maps_import\Mapping\Target\Drupal\Relation;

class Link extends Mapping {

	/**
	 * The entities correspondance table.
	 */
	const DB_ENTITIES_TABLE = 'maps_links_entities';
	
  /**
   * @inheritdoc
   */ 
  protected $type = 'link_mapping';

  /**
   * @inheritdoc
   */
  public function getSourceProperties() {
    // @todo use a cache class.
    // @todo handle languages
    static $properties;

    if (!isset($properties)) {
      $properties = parent::buildSourcePropertyHandlers(array(
        'count' => array('title' => 'Count'),
      ));
    }

    return $properties;
  }

  /**
   * @inheritdoc
   * @todo implement log. 
   */
  public function process(MS\Entity $entity) {
    self::$currentEntity = $entity;

    // Log source and target properties
    Mapper::log()
      ->addContext(new LogContext('source'), 'child')->addContext(new LogContext('properties'), 'child')
      ->addContext(new LogContext('source_object'), 'child')->addContext(new LogContext('value'), 'child')->addMessage($entity->getSource())
      ->moveToParent('properties')
      ->addContext(new LogContext('target_object'), 'child')->addContext(new LogContext('value'), 'child')->addMessage($entity->getTarget())
      ->moveToParent('properties');
      
    try {    	
      // Set raw values in MaPS Entity.
      foreach ($this->getItems() as $item) {
        $entity->setRawValues($item->getProperty(), $item->getOptions());
      }
        
      Mapper::log()
        ->moveToParent('source')
        ->moveToParent()
        ->addContext(new LogContext('target'), 'child')
        ->addContext(new LogContext('fields'), 'child');
            
      // Create a new Drupal Entity.
      $drupalEntity = new Relation($this->getConverter(), array());

      // Set values in Drupal Entity.
      foreach ($this->getItems() as $item) {
        $drupalEntity->getTranslationHandler()->setValue($item->getField(), $item->getProperty(), $entity, $item->isRequired());
      }
      
	    try { 
        $drupalEntity->save();      
        $identifiers = $drupalEntity->getIdentifiers();

        foreach ($identifiers as $identifier) {
        	db_insert(self::DB_ENTITIES_TABLE)
        	  ->fields(array(
              'pid' => $this->getConverter()->getProfile()->getPid(),
              'cid' => $this->getConverter()->getCid(),
        	    'entity_id' => $identifier,
        	  ))
        	  ->execute();
        }        
	    }
	    catch (MappingException $e) {	      
	      return array(); 
	    }
		    
	    return array($entity, $drupalEntity);
	  }
    catch (MappingException $e) {
      return array(); 
    }  
  }
  
  /**
   * @inheritdoc
   */
  public function getTargetFields() {
  	$fields = parent::getTargetFields();
  	unset($fields['endpoints']);
  	return $fields;
  } 
}

==> maps_suite-7.x-2.23.tar.gz: maps_suite/modules/links/lib/Drupal/maps_links/Mapping/Link.php <==
<?php

namespace Drupal\maps_links\Mapping;

use Drupal\maps_import\Mapping\Mapping;
use Drupal\maps_import\Mapping\Source\MapsSystem as MS;
use Drupal\maps_links\Mapping\Target\Drupal\Relation;
use Drupal\maps_import\Cache\Data\MappingItems as CacheMappingItems;

class Link extends Mapping {

	/**
	 * The entities correspondance table.
	 */
	const DB_ENTITIES_TABLE = 'maps_links_entities';

  /**
   * @inheritdoc
   */
  protected $type = 'link_mapping';

  /**
   * @inheritdoc
   */
  public function getSourceProperties() {
    // @todo use a cache class.
    // @todo handle languages
    static $properties;

    if (!isset($properties)) {
      $properties = parent::buildSourcePropertyHandlers(array(
        'count' => array('title' => 'Count'),
      ));
    }

    return $properties;
  }

  /**
   * @inheritdoc
   * @todo implement log.
   */
  public function process(MS\Entity $entity) {
    self::$currentEntity = $entity;

    try {
      // Set raw values in MaPS Entity.
      foreach ($this->getItems() as $item) {
        $entity->setRawValues($item->getProperty(), $item->getOptions());
      }

      // Create a new Drupal Entity.
      $drupalEntity = new Relation($this->getConverter(), array());

      // Set values in Drupal Entity.
      foreach ($this->getItems() as $item) {
        $drupalEntity->getTranslationHandler()->setValue($item->getField(), $item->getProperty(), $entity, $item->isRequired());
      }

	    try {
        $drupalEntity->save();
        $identifiers = $drupalEntity->getIdentifiers();

        foreach ($identifiers as $identifier) {
        	db_insert(self::DB_ENTITIES_TABLE)
        	  ->fields(array(
              'link_id' => $entity->id,
              'pid' => $this->getConverter()->getProfile()->getPid(),
              'cid' => $this->getConverter()->getCid(),
        	    'relation_id' => $identifier,
        	  ))
        	  ->execute();
        }
	    }
	    catch (MappingException $e) {
	      return array();
	    }

	    return array($entity, $drupalEntity);
	  }
    catch (MappingException $e) {
      return array();
    }
  }
  
  /**
   * @inheritdoc
   */
  public function getTargetFields() {
  	$fields = parent::getTargetFields();
  	unset($fields['endpoints']);
  	return $fields;
  }
  
  /**
   * @inheritdoc
   */
  public function getItems($type = 'default') {
    return CacheMappingItems::getInstance()->load(array(
      'converter' => $this->getConverter(),
      'type' => 'link',
    ));
  }
}
